==> kvirc_2.1.3.orig.tar.gz: kvirc-2.1.3/src/kvilib/kde/kvi_tabdialog_kde.cpp <==
// =============================================================================
//
//      --- kvi_tabdialog_kde.cpp ---
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 2003 Robin Verduijn <robin@debian.org>
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// =============================================================================

#include "kvi_tabdialog_kde.h"

KviTabDialog::KviTabDialog(QWidget *parent, const char *name, bool modal, const QString &caption, int buttonMask)
	: KDialogBase(Tabbed, caption, buttonMask, Ok, parent, name, modal)
{
	// Nothing here
}

KviTabDialog::~KviTabDialog()
{
	// Nothing here
}

void KviTabDialog::showPageForWidget(QWidget *w)
{
	KDialogBase::showPage(pageIndex(w));
}

void KviTabDialog::setButtonDefaultText(const QString &text)
{
	setButtonText(Default, text);
}

void KviTabDialog::setButtonHelpText(const QString &text)
{
	setButtonText(Help, text);
}

void KviTabDialog::slotHelp()
{
	emit helpClicked();
}

#include "m_kvi_tabdialog_kde.moc"

==> kvirc2_2.1.3.orig.tar.gz: kvirc2-2.1.3/src/kvilib/kde/kvi_tabdialog_kde.cpp <==
// =============================================================================
//
//      --- kvi_tabdialog_kde.cpp ---
//
//   This file is part of the KVIrc IRC client distribution
//   Copyright (C) 2003 Robin Verduijn <robin@debian.org>
//
//   This program is FREE software. You can redistribute it and/or
//   modify it under the terms of the GNU General Public License
//   as published by the Free Software Foundation; either version 2
//   of the License, or (at your opinion) any later version.
//
//   This program is distributed in the HOPE that it will be USEFUL,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//   See the GNU General Public License for more details.
//
//   You should have received a copy of the GNU General Public License
//   along with this program. If not, write to the Free Software Foundation,
//   Inc, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// =============================================================================

#include "kvi_tabdialog_kde.h"

#if ! KDE_IS_VERSION(3,2,0)
	#include "kvi_locale.h"
#endif

KviTabDialog::KviTabDialog(QWidget *parent, const char *name, bool modal, const QString &caption, int buttonMask)
	: KDialogBase(Tabbed, caption, buttonMask, Ok, parent, name, modal)
{
	// Nothing here
}

KviTabDialog::~KviTabDialog()
{
	// Nothing here
}

void KviTabDialog::showPageForWidget(QWidget *w)
{
	KDialogBase::showPage(pageIndex(w));
}

void KviTabDialog::setButtonDefaultText(const QString &text)
{
	setButtonText(Default, text);
}

void KviTabDialog::setButtonHelpText(const QString &text)
{
	setButtonText(Help, text);
}

void KviTabDialog::slotHelp()
{
	emit helpClicked();
}

#if ! KDE_IS_VERSION(3,2,0)
void KviTabDialog::setButtonOK()
{
	setButtonOKText(_i18n_("&OK"));
}

void KviTabDialog::setButtonCancel()
{
	setButtonCancelText(_i18n_("&Cancel"));
}
#endif

#include "m_kvi_tabdialog_kde.moc"
